@@ -46,3 +46,60 @@ package WebGPU::Direct::Instance
 };
 
 1;
+__END__
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+WebGPU::Direct::Instance
+
+=head2 Methods
+
+=head3 CreateSurface
+
+=over
+
+=item * Return Type
+
+=over
+
+=item * WGPUSurface
+
+=back
+
+=item * Arguments
+
+=over
+
+=item * descriptor (L<WebGPU::Direct::SurfaceDescriptor|WebGPU::Direct::Types/WebGPU::Direct::SurfaceDescriptor>)
+
+=back
+
+=back
+
+=head3 ProcessEvents
+
+=head3 RequestAdapter
+
+=over
+
+=item * Arguments
+
+=over
+
+=item * options (L<WebGPU::Direct::RequestAdapterOptions|WebGPU::Direct::Types/WebGPU::Direct::RequestAdapterOptions>)
+
+=item * callback (L<WebGPU::Direct::RequestAdapterCallback>)
+
+=item * userdata (L<WebGPU::Direct::void>)
+
+=back
+
+=back
+
+=head3 Reference
+
+=head3 Release
+
